@@ -1,6 +1,7 @@
 import dataclasses
 import json
 from pathlib import Path
+from typing import List
 
 from helix_personmatching.logics.match_score import MatchScore
 from helix_personmatching.matchers.matcher import Matcher
@@ -17,10 +18,12 @@ def test_exact_match() -> None:
 
     matcher = Matcher()
 
-    score: MatchScore = matcher.match(
+    scores: List[MatchScore] = matcher.match(
         source_json=resource1_json, target_json=resource2_json, verbose=True
     )
 
+    assert len(scores) == 1
+    score = scores[0]
     assert score.matched is True
 
     assert score.total_score == 87.76455026455027
